Function postgresql_extensions::zip_matcher
source · pub fn zip_matcher(url: &str, name: &str, version: &Version) -> Result<bool>Expand description
.zip asset matcher that matches the asset name to the postgresql major version, target triple or OS/CPU architecture.
Errors
- If the asset matcher fails.